-
Notifications
You must be signed in to change notification settings - Fork 8
Commit
This commit does not belong to any branch on this repository, and may belong to a fork outside of the repository.
build: patch
@semantic-release/github
- Loading branch information
Showing
4 changed files
with
43 additions
and
5 deletions.
There are no files selected for viewing
This file contains bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
This file contains bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
Original file line number | Diff line number | Diff line change |
---|---|---|
|
@@ -91,6 +91,9 @@ | |
}, | ||
"neverBuiltDependencies": [ | ||
"dtrace-provider" | ||
] | ||
], | ||
"patchedDependencies": { | ||
"@semantic-release/[email protected]": "patches/@[email protected]" | ||
} | ||
} | ||
} |
This file contains bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
Original file line number | Diff line number | Diff line change |
---|---|---|
@@ -0,0 +1,29 @@ | ||
diff --git a/lib/octokit.js b/lib/octokit.js | ||
index 798b5756c8bd47c7d800fb788bd1ecfe165b1371..12c8cc538e586ab9ffcfd06f095b5a17e443f7f7 100644 | ||
--- a/lib/octokit.js | ||
+++ b/lib/octokit.js | ||
@@ -2,6 +2,7 @@ | ||
// @ts-check | ||
|
||
import { createRequire } from "node:module"; | ||
+import fetch from 'node-fetch'; | ||
|
||
// If maintaining @octokit/core and the separate plugins gets to cumbersome | ||
// then the `octokit` package can be used which has all these plugins included. | ||
@@ -50,7 +51,7 @@ export const SemanticReleaseOctokit = Octokit.plugin( | ||
|
||
/** | ||
* @param {{githubToken: string, proxy: any} | {githubUrl: string, githubApiPathPrefix: string, githubToken: string, proxy: any}} options | ||
* @returns {{ auth: string, baseUrl?: string, request: { agent?: any } }} | ||
*/ | ||
export function toOctokitOptions(options) { | ||
const baseUrl = | ||
@@ -71,6 +72,7 @@ export function toOctokitOptions(options) { | ||
auth: options.githubToken, | ||
request: { | ||
agent, | ||
+ fetch, | ||
}, | ||
}; | ||
} |
@@ -50,7 +51,7 @@ export const SemanticReleaseOctokit = Octokit.plugin( | ||
/** | ||
* @param {{githubToken: string, proxy: any} | {githubUrl: string, githubApiPathPrefix: string, githubToken: string, proxy: any}} options | ||
- * @returns {{ auth: string, baseUrl?: string, request: { agent?: any } }} | ||
+ * @returns {{ auth: string, baseUrl?: string, request: { agent?: any, fetch?: any } }} | ||
*/ | ||
export function toOctokitOptions(options) { | ||
Some generated files are not rendered by default. Learn more about how customized files appear on GitHub.
Oops, something went wrong.